#include <iostream>
#include <random>
#include <vector>
#include <tuple>
#include <ctime>
#include <cmath>
#include <iomanip>

typedef std::tuple<double, double> point;

std::ostream& operator<<(std::ostream& out, const point& pt) {
	out << "( " << std::get<0>(pt) << ", " <<  std::get<1>(pt) << ") ";
	return out;
}

std::default_random_engine e(time(nullptr));

point random_point() {
	std::uniform_real_distribution<double> u(0,1);
	point temp;
	std::get<0>(temp) = u(e);
	std::get<1>(temp) = u(e);
	return temp;
}

double mc_integral(double f(double), std::vector<point>::iterator first, 
                   std::vector<point>::iterator last) {
	int total = 0;
	int below = 0;
	for (; first != last; ++first) {
		++total;
		if (f(std::get<0>(*first)) > std::get<1>(*first))
			++below;
	}
	return static_cast<double>(below) / total;
}

int main(void) {
	int data_size;
	std::cout << "Koliko slucajnih tocaka zelite generirati? ";
	std::cin >> data_size;
	std::vector<point> data(data_size);

	for (auto& element : data)
		element = random_point();

	std::cout << "PI (Monte Carlo) = " << std :: setprecision (17) <<
	   4.0 * mc_integral([](double x){return sqrt(1 - x * x);}, data.begin(), data.end());
	std::cout << std::endl;

	return 0;
}
