#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>
#include <cmath>
#include <iomanip>

// generator za podintegralnu funkciju, u ovom slucaju f(x)=sqrt(1-x^2)
class gen {
private:
	double x, dx;
public:
	gen(double x0, double pomak) : x(x0), dx(pomak) {}
	double operator()() {
		x += dx;
		return sqrt(1.0 - std::min(1.0, x * x));
	}
};

// racunanje vrijednosti integralne sume funkcije f(x)=sqrt(1-x^2) na segmentu [0,1]
double integrate(gen g, int n) {
	std::vector<double> fx(n);
	std::generate(fx.begin(), fx.end(), g);
	return (std::accumulate(fx.begin(), fx.end(), 0.0) / n);
}

int main(void) {
	int n;
	std::cout << "\nNa koliko dijelova podijeliti segment [0,1]: ";
	std::cin >> n;

	gen g(0, 1.0/n);
	std::cout <<std::endl;
	std::cout << "-------------------------------------------------" << std::endl;
	std::cout << "Dobivanje decimala broja PI preko integralne sume" << std::endl;
	std::cout << "-------------------------------------------------" << std::endl;
	std::cout << std::setprecision(17) << 4 * integrate(g, n) << std::endl;
	std::cout << std::endl;

	return 0;
}
